create_rpc_runtime

Function create_rpc_runtime 

pub fn create_rpc_runtime(max_connections: u32) -> Result<Runtime>
Creates a dedicated tokio runtime for RPC operations.

This runtime isolates RPC blocking operations from the rest of the node by limiting the number of blocking threads to max_connections.